@@ -1,25 +1,31 @@
 #!/usr/bin/env python
 
-import os
 import sys
 import subprocess
 import getopt
 import unittest
+from lxml import etree
 
 
 class GenTest(unittest.TestCase):
-    def execute(self, cmd, cwd = None):
-        p = subprocess.Popen(cmd, cwd=cwd,
+    def execute(self, cmd, cwd=None):
+        p = subprocess.Popen(
+            cmd, cwd=cwd,
             stdout=subprocess.PIPE, stderr=subprocess.PIPE,
             shell=True)
         stdout, stderr = p.communicate()
         return stdout, stderr
 
-    def setUp(self):
-        cmd = 'python generateDS.py --no-dates --no-versions -f -o tests/out2_sup.py -s tests/out2_sub.py --super=out2_sup -u gends_user_methods tests/people.xsd'
-        stdout, stderr = self.execute(cmd, cwd='..')
-        self.failUnlessEqual(len(stdout), 0)
-        self.failUnlessEqual(len(stderr), 0)
+##     def setUp(self):
+##         print 'running setUp'
+##         cmd = (
+##             'python generateDS.py --no-dates --no-versions -f '
+##             '-o tests/out2_sup.py -s tests/out2_sub.py '
+##             '--super=out2_sup -u gends_user_methods tests/people.xsd'
+##         )
+##         stdout, stderr = self.execute(cmd, cwd='..')
+##         self.failUnlessEqual(len(stdout), 0)
+##         self.failUnlessEqual(len(stderr), 0)
 
 ##     def tearDown(self):
 ##         for f in [ "out2_sub.py", "out2_sup.py" ]:
@@ -29,14 +35,20 @@ class GenTest(unittest.TestCase):
 ##                 pass
 
     def test_001_compare_superclasses(self):
+        cmd = (
+            'python generateDS.py --no-dates --no-versions -f '
+            '-o tests/out2_sup.py -s tests/out2_sub.py '
+            '--super=out2_sup -u gends_user_methods tests/people.xsd'
+        )
+        stdout, stderr = self.execute(cmd, cwd='..')
+        self.failUnlessEqual(len(stdout), 0)
+        self.failUnlessEqual(len(stderr), 0)
         cmd = 'diff out1_sup.py out2_sup.py'
         result, err = self.execute(cmd)
         #print 'len(result):', len(result)
         # Ignore the differing lines containing the date/time.
         #self.failUnless(len(result) < 130 and result.find('Generated') > -1)
         self.check_result(result, err, ())
-
-    def test_002_compare_subclasses(self):
         cmd = 'diff out1_sub.py out2_sub.py'
         result, err = self.execute(cmd)
         # Ignore the differing lines containing the date/time.
@@ -44,12 +56,21 @@ class GenTest(unittest.TestCase):
         self.check_result(result, err, ())
 
     def test_003_element_groups(self):
-        cmdTempl = 'python generateDS.py --no-dates --silence --member-specs=list -f -o tests/%s_sup.py -s tests/%s_sub.py --super=%s_sup tests/%s.xsd'
+        cmdTempl = (
+            'python generateDS.py --no-dates --silence '
+            '--member-specs=list -f '
+            '-o tests/%s_sup.py -s tests/%s_sub.py '
+            '--super=%s_sup tests/%s.xsd'
+        )
         t_ = 'groups'
         cmd = cmdTempl % (t_, t_, t_, t_)
         result, err = self.execute(cmd, cwd='..')
         # Verify the structure
-        cmdTempl = '''python -c "import %s_sub; print [ x.name for x in %s_sub.node1TypeSub.member_data_items_ ]; print [ x.name for x in %s_sub.node2TypeSub.member_data_items_ ]"'''
+        cmdTempl = (
+            'python -c "import %s_sub; print '
+            '[ x.name for x in %s_sub.node1TypeSub.member_data_items_ ]; '
+            'print [ x.name for x in %s_sub.node2TypeSub.member_data_items_ ]"'
+        )
         cmd = cmdTempl % (t_, t_, t_)
         result, err = self.execute(cmd)
         self.failUnlessEqual(result, """\
@@ -57,7 +78,14 @@ class GenTest(unittest.TestCase):
 ['node2node1', 'group1', 'group2', 'node2node2']
 """)
         # load the XML, and verify the proper data was loaded
-        cmdTempl = '''python -c "import %s_sub; obj = %s_sub.parse('%s.xml'); fields = [ x.name for x in obj.node1.member_data_items_ ]; print [ getattr(obj.node1, x) for x in fields ]; fields = [ x.name for x in obj.node2.member_data_items_ ]; print [ getattr(obj.node2, x) for x in fields ]"'''
+        cmdTempl = (
+            'python -c "import %s_sub; obj = '
+            '%s_sub.parse(\'%s.xml\'); fields = '
+            '[ x.name for x in obj.node1.member_data_items_ ]; '
+            'print [ getattr(obj.node1, x) for x in fields ]; '
+            'fields = [ x.name for x in obj.node2.member_data_items_ ]; '
+            'print [ getattr(obj.node2, x) for x in fields ]"'
+        )
         cmd = cmdTempl % (t_, t_, t_)
         result, err = self.execute(cmd)
         self.failUnlessEqual(result, """\
@@ -66,7 +94,12 @@ class GenTest(unittest.TestCase):
 """)
 
     def test_004_valueof(self):
-        cmdTempl = 'python generateDS.py --no-dates --silence --member-specs=list -f -o tests/%s_sup.py -s tests/%s_sub.py --super=%s_sup tests/%s.xsd'
+        cmdTempl = (
+            'python generateDS.py --no-dates --silence '
+            '--member-specs=list -f '
+            '-o tests/%s_sup.py -s tests/%s_sub.py '
+            '--super=%s_sup tests/%s.xsd'
+        )
         t_ = 'valueof'
         cmd = cmdTempl % (t_, t_, t_, t_)
         result, err = self.execute(cmd, cwd='..')
@@ -77,7 +110,11 @@ class GenTest(unittest.TestCase):
         #     children = obj.get_child()
         #     print [ (x.get_name(), x.get_valueOf_()) for x in children ]
         #
-        cmdTempl = '''python -c "import %s_sub; obj = %s_sub.parse('%s.xml'); children = obj.get_child(); print [ (x.get_name(), x.get_valueOf_()) for x in children ]"'''
+        cmdTempl = (
+            'python -c "import %s_sub; obj = '
+            '%s_sub.parse(\'%s.xml\'); children = obj.get_child(); '
+            'print [ (x.get_name(), x.get_valueOf_()) for x in children ]"'
+        )
         cmd = cmdTempl % (t_, t_, t_)
         result, err = self.execute(cmd)
         self.failUnlessEqual(result, """\
@@ -87,14 +124,20 @@ class GenTest(unittest.TestCase):
         # in
         # Run these commands::
         #     import valueof_sub
-        #     node = valueof_sub.childTypeSub.factory(name='child1', valueOf_ = 'value1')
+        #     node = valueof_sub.childTypeSub.factory(
+        #             name='child1', valueOf_ = 'value1')
         #     print (node.get_name(), node.get_valueOf_())
 
-        cmdTempl = '''python -c "import %s_sub; node = %s_sub.childTypeSub.factory(name='child1', valueOf_ = 'value1'); print (node.get_name(), node.get_valueOf_())"'''
+        cmdTempl = (
+            'python -c "import %s_sub; '
+            'node = %s_sub.childTypeSub.factory(name=\'child1\', '
+            'valueOf_ = \'value1\'); '
+            'print (node.get_name(), node.get_valueOf_())"'
+        )
         cmd = cmdTempl % (t_, t_)
-        print 'cmd:', cmd
+        #print 'cmd:', cmd
         result, err = self.execute(cmd)
-        print 'result: %s' % result
+        #print 'result: %s' % result
         self.failUnlessEqual(result, """\
 ('child1', 'value1')
 """)
@@ -129,17 +172,21 @@ class GenTest(unittest.TestCase):
 """
 
     def test_005_ns_for_import(self):
-        from lxml import etree
         root1 = etree.fromstring(GenTest.ns_for_import_xml1)
         root2 = etree.fromstring(GenTest.ns_for_import_xml2)
         for child in root2.getchildren():
             root1.append(child.__copy__())
         #print etree.tostring(root1, pretty_print = True)
-        result = etree.tostring(root1, pretty_print = True)
+        result = etree.tostring(root1, pretty_print=True)
         self.failUnlessEqual(GenTest.ns_for_import_xml_result, result)
 
     def test_006_anysimpletype(self):
-        cmdTempl = 'python generateDS.py --no-dates --no-versions --silence --member-specs=list -f -o tests/%s2_sup.py -s tests/%s2_sub.py --super=%s2_sup tests/%s.xsd'
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup tests/%s.xsd'
+        )
         t_ = 'anysimpletype'
         cmd = cmdTempl % (t_, t_, t_, t_, )
         result, err = self.execute(cmd, cwd='..')
@@ -151,7 +198,12 @@ class GenTest(unittest.TestCase):
         self.check_result(result, err, ())
 
     def test_007_simpletype_memberspecs(self):
-        cmdTempl = 'python generateDS.py --no-dates --no-versions --silence --member-specs=list -f -o tests/%s2_sup.py -s tests/%s2_sub.py --super=%s2_sup tests/%s.xsd'
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup tests/%s.xsd'
+        )
         t_ = 'simpletype_memberspecs'
         cmd = cmdTempl % (t_, t_, t_, t_, )
         result, _ = self.execute(cmd, cwd='..')
@@ -163,7 +215,12 @@ class GenTest(unittest.TestCase):
         self.check_result(result, err, ())
 
     def test_008_extensions(self):
-        cmdTempl = 'python generateDS.py --no-dates --no-versions --silence --member-specs=list -f -o tests/%s2_sup.py -s tests/%s2_sub.py --super=%s2_sup tests/%s.xsd'
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup tests/%s.xsd'
+        )
         t_ = 'extensions'
         cmd = cmdTempl % (t_, t_, t_, t_, )
         result, _ = self.execute(cmd, cwd='..')
@@ -189,8 +246,13 @@ class GenTest(unittest.TestCase):
         infile.close()
         self.failUnlessEqual(content1, content2)
 
-    def test_010_extensions(self):
-        cmdTempl = 'python generateDS.py --no-dates --no-versions --silence --member-specs=list -f -o tests/%s2_sup.py -s tests/%s2_sub.py --super=%s2_sup tests/%s.xsd'
+    def test_010_simplecontent_restriction(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup tests/%s.xsd'
+        )
         t_ = 'simplecontent_restriction'
         cmd = cmdTempl % (t_, t_, t_, t_, )
         result, _ = self.execute(cmd, cwd='..')
@@ -201,9 +263,13 @@ class GenTest(unittest.TestCase):
         result, err = self.execute(cmd)
         self.check_result(result, err, ())
 
-
     def test_011_annotations(self):
-        cmdTempl = 'python generateDS.py --no-dates --no-versions --silence --member-specs=list -f -o tests/%s2_sup.py -s tests/%s2_sub.py --super=%s2_sup tests/%s.xsd'
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup tests/%s.xsd'
+        )
         t_ = 'annotations'
         cmd = cmdTempl % (t_, t_, t_, t_, )
         result, _ = self.execute(cmd, cwd='..')
@@ -214,9 +280,13 @@ class GenTest(unittest.TestCase):
         result, err = self.execute(cmd)
         self.check_result(result, err, ())
 
-
-    def test_012_abstracttype(self):
-        cmdTempl = 'python generateDS.py --no-dates --no-versions --silence --member-specs=list -f -o tests/%s2_sup.py -s tests/%s2_sub.py --super=%s2_sup tests/%s.xsd'
+    def test_012_abstract_type(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup tests/%s.xsd'
+        )
         t_ = 'abstract_type'
         cmd = cmdTempl % (t_, t_, t_, t_, )
         result, _ = self.execute(cmd, cwd='..')
@@ -227,14 +297,14 @@ class GenTest(unittest.TestCase):
         result, err = self.execute(cmd)
         self.check_result(result, err, ())
 
-
-    def test_013_procincl(self):
-        cmdTempl = ('python generateDS.py --no-dates --no-versions '
+    def test_013_people_procincl(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
             '--silence --member-specs=list -f '
             '-o tests/%s2_sup.py -s tests/%s2_sub.py '
             '--super=%s2_sup '
             'tests/%s.xsd'
-            )
+        )
         t_ = 'people_procincl'
         cmd = cmdTempl % (t_, t_, t_, t_, )
         result, _ = self.execute(cmd, cwd='..')
@@ -245,9 +315,13 @@ class GenTest(unittest.TestCase):
         result, err = self.execute(cmd)
         self.check_result(result, err, ())
 
-
-    def test_014_xsi_type(self):
-        cmdTempl = 'python generateDS.py --no-dates --no-versions --member-specs=list -f -o tests/%s2_sup.py -s tests/%s2_sub.py --super=%s2_sup tests/%s.xsd'
+    def test_014_ipo(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup tests/%s.xsd'
+        )
         t_ = 'ipo'
         cmd = cmdTempl % (t_, t_, t_, t_, )
         result, _ = self.execute(cmd, cwd='..')
@@ -264,14 +338,14 @@ class GenTest(unittest.TestCase):
         result, err = self.execute(cmd)
         self.check_result(result, err, ())
 
-
     def test_015_recursive_simpletype(self):
-        cmdTempl = ('python generateDS.py --no-dates --no-versions '
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
             '--silence --member-specs=list -f '
             '-o tests/%s2_sup.py -s tests/%s2_sub.py '
             '--super=%s2_sup '
             'tests/%s.xsd'
-            )
+        )
         t_ = 'recursive_simpletype'
         cmd = cmdTempl % (t_, t_, t_, t_, )
         result, _ = self.execute(cmd, cwd='..')
@@ -282,14 +356,14 @@ class GenTest(unittest.TestCase):
         result, err = self.execute(cmd)
         self.check_result(result, err, ())
 
-
     def test_016_anywildcard(self):
-        cmdTempl = ('python generateDS.py --no-dates --no-versions '
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
             '--silence --member-specs=list -f '
             '-o tests/%s2_sup.py -s tests/%s2_sub.py '
             '--super=%s2_sup '
             'tests/%s.xsd'
-            )
+        )
         t_ = 'anywildcard'
         cmd = cmdTempl % (t_, t_, t_, t_, )
         result, _ = self.execute(cmd, cwd='..')
@@ -300,6 +374,138 @@ class GenTest(unittest.TestCase):
         result, err = self.execute(cmd)
         self.check_result(result, err, ())
 
+    def test_017_attr_groups(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup '
+            'tests/%s.xsd'
+        )
+        t_ = 'attr_groups'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff %s1_sup.py %s2_sup.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff %s1_sub.py %s2_sub.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+
+    def test_018_simpletypes_other(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup '
+            'tests/%s.xsd'
+        )
+        t_ = 'simpletypes_other'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff %s1_sup.py %s2_sup.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff %s1_sub.py %s2_sub.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+
+    def test_019_to_etree(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--export="etree" --silence '
+            '--super=%s2_sup '
+            'tests/%s.xsd'
+        )
+        t_ = 'to_etree'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff %s1_sup.py %s2_sup.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff %s1_sub.py %s2_sub.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+        import to_etree2_sup
+        rootObj, rootElement, mapping, reverse_mapping = \
+            to_etree2_sup.parseEtree('to_etree.xml')
+        content = etree.tostring(
+            rootElement, pretty_print=True,
+            xml_declaration=True, encoding="utf-8")
+        outfile = open('to_etree2.xml', 'w')
+        outfile.write(content)
+        outfile.close()
+        cmd = 'diff %s1.xml %s2.xml' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+
+    def test_020_catalogtest(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup '
+            '-c tests/catalog.xml '
+            'tests/%s.xsd'
+        )
+        t_ = 'catalogtest'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff %s1_sup.py %s2_sup.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff %s1_sub.py %s2_sub.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+
+    def test_021_anonymous_type(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup '
+            'tests/%s.xsd'
+        )
+        t_ = 'anonymous_type'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff %s1_sup.py %s2_sup.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff %s1_sub.py %s2_sub.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+
+    def test_022_one_per(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '--one-file-per-xsd --output-directory="tests/OnePer" '
+            '--module-suffix="One" '
+            '--super=%s2_sup '
+            'tests/%s00.xsd'
+        )
+        t_ = 'oneper'
+        cmd = cmdTempl % (t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff OnePer/%sType00_1One.py OnePer/%sType00_2One.py' % (
+            t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff OnePer/%sType01_1One.py OnePer/%sType01_2One.py' % (
+            t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff OnePer/%sType02_1One.py OnePer/%sType02_2One.py' % (
+            t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff OnePer/%sType03_1One.py OnePer/%sType03_2One.py' % (
+            t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
 
     def check_result(self, result, err, ignore_strings):
         self.failUnlessEqual(len(result), 0)
@@ -327,7 +533,7 @@ class GenTest(unittest.TestCase):
 def suite():
     # The following is obsolete.  See Lib/unittest.py.
     #return unittest.makeSuite(GenTest)
-    loader = unittest.TestLoader()
+    loader = unittest.defaultTestLoader
     testsuite = loader.loadTestsFromTestCase(GenTest)
     return testsuite
 
@@ -348,6 +554,7 @@ Example:
     python test.py
 """
 
+
 def usage():
     print USAGE_TEXT
     sys.exit(-1)
@@ -359,7 +566,6 @@ def main():
         opts, args = getopt.getopt(args, 'h', ['help'])
     except:
         usage()
-    relink = 1
     for opt, val in opts:
         if opt in ('-h', '--help'):
             usage()
@@ -372,4 +578,3 @@ if __name__ == '__main__':
     main()
     #import pdb
     #pdb.run('main()')
-
